==> image-saas-client-0.0.703-sources.jar: com/xforceplus/ultraman/app/imagesaas/controller/SystemLabelsHistoryFeignApi.java <==
package com.xforceplus.ultraman.app.imagesaas.controller;


/**
 * ${table.comment}feign客户端
 *
 * @author ultraman
 * @date 2022-04-06
 */
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.GetMapping;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.extension.api.R;
import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import com.xforceplus.ultraman.app.imagesaas.entity.SystemLabelsHistory;
import lombok.AllArgsConstructor;
import org.springframework.stereotype.Controller;
import java.util.List;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;


@FeignClient(name = "image-saas")
public interface SystemLabelsHistoryFeignApi {

  /**
   * 通过id查询${table.comment}
   * @param  id
   * @return R
   */
  @GetMapping("/systemLabelsHistory/get/{id}" )
  public R getById(@PathVariable Long id);

  /**
   * 新增${table.comment}
   * @param systemLabelsHistory ${table.comment}
   * @return R
   */
  @PostMapping("/systemLabelsHistory/add")
  public R save(@RequestBody SystemLabelsHistory systemLabelsHistory);

  /**
   * 修改${table.comment}
   * @param systemLabelsHistory ${table.comment}
   * @return R
   */
  @PostMapping("/systemLabelsHistory/update")
  public R updateById(@RequestBody SystemLabelsHistory systemLabelsHistory);

  /**
   * 通过id删除${table.comment}
   * @param  id
   * @return R
   */
  @DeleteMapping("/systemLabelsHistory/del/{id}" )
  public R removeById(@PathVariable Long id);

}

==> image-saas-client-0.1.148-sources.jar: com/xforceplus/ultraman/app/imagesaas/controller/SystemLabelsHistoryFeignApi.java <==
package com.xforceplus.ultraman.app.imagesaas.controller;


/**
 * ${table.comment}feign客户端
 *
 * @author ultraman
 * @date 2023-03-28
 */
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.GetMapping;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.extension.api.R;
import org.apache.commons.lang3.StringUtils;
import com.xforceplus.ultraman.app.imagesaas.entity.SystemLabelsHistory;
import lombok.AllArgsConstructor;
import org.springframework.stereotype.Controller;
import java.util.List;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;


@FeignClient(name = "image-saas")
public interface SystemLabelsHistoryFeignApi {

  /**
   * 通过id查询${table.comment}
   * @param  id
   * @return R
   */
  @GetMapping("/systemLabelsHistory/get/{id}" )
  public R getById(@PathVariable Long id);

  /**
   * 新增${table.comment}
   * @param systemLabelsHistory ${table.comment}
   * @return R
   */
  @PostMapping("/systemLabelsHistory/add")
  public R save(@RequestBody SystemLabelsHistory systemLabelsHistory);

  /**
   * 修改${table.comment}
   * @param systemLabelsHistory ${table.comment}
   * @return R
   */
  @PostMapping("/systemLabelsHistory/update")
  public R updateById(@RequestBody SystemLabelsHistory systemLabelsHistory);

  /**
   * 通过id删除${table.comment}
   * @param  id
   * @return R
   */
  @DeleteMapping("/systemLabelsHistory/del/{id}" )
  public R removeById(@PathVariable Long id);

}
